@@ -520,10 +520,11 @@ class Collection(object):
             key[keys[i]] = obj[keys[i]];
         }
 
-        var aggObj = map[key];
+        var aggObj = map.get(key);
         if (aggObj == null) {
             var newObj = Object.extend({}, key);
-            aggObj = map[key] = Object.extend(newObj, initial);
+            aggObj = Object.extend(newObj, initial);
+            map.put(key, aggObj);
         }
         reduce_function(obj, aggObj);
     }
@@ -541,7 +542,7 @@ class Collection(object):
     def next(self):
         raise TypeError("'Collection' object is not iterable")
 
-    def __call__(self):
+    def __call__(self, *args, **kwargs):
         """This is only here so that some API misusages are easier to debug.
         """
         if "." not in self.__collection_name:
